@@ -55,8 +55,8 @@ class Context(context.RequestContext):
                         '{args}'.format(args=kwargs))
 
         super(Context, self).__init__(auth_token=auth_token,
-                                      user=user_id,
-                                      tenant=tenant_id,
+                                      user_id=user_id,
+                                      project_id=tenant_id,
                                       is_admin=is_admin,
                                       resource_uuid=resource_uuid,
                                       request_id=request_id,
@@ -105,12 +105,12 @@ class Context(context.RequestContext):
         return d
 
     def is_auth_capable(self):
-        return (self.service_catalog and self.auth_token and self.tenant and
-                self.user_id)
+        return (self.service_catalog and self.auth_token and self.project_id
+                and self.user_id)
 
-    # NOTE(adrienverge): The Context class uses the 'user' and 'tenant'
-    # properties internally (inherited from oslo_context), but Sahara code
-    # often uses 'user_id' and 'tenant_id'.
+    # NOTE(adrienverge): The Context class uses the 'tenant' property
+    # internally (inherited from oslo_context), but Sahara code often uses
+    # 'tenant_id'.
     @property
     def user_id(self):
         return self.user
@@ -121,11 +121,11 @@ class Context(context.RequestContext):
 
     @property
     def tenant_id(self):
-        return self.tenant
+        return self.project_id
 
     @tenant_id.setter
     def tenant_id(self, value):
-        self.tenant = value
+        self.project_id = value
 
 
 def get_admin_context():
