@@ -48,8 +48,12 @@ def _create_facade_lazily():
     if _FACADE is None:
         with _LOCK:
             if _FACADE is None:
+                # FIXME(amoralej): Remove autocommit=True (and ideally use of
+                # LegacyEngineFacade) asap since it's not compatible with
+                # SQLAlchemy 2.0.
                 _FACADE = db_session.EngineFacade.from_config(CONF,
-                                                              sqlite_fk=True)
+                                                              sqlite_fk=True,
+                                                              autocommit=True)
     return _FACADE
 
 
@@ -1561,7 +1565,7 @@ def cluster_verification_add(context, cluster_id, values):
         verification.update(values)
         session.add(verification)
 
-    return verification
+    return _cluster_verification_get(context, session, verification.id)
 
 
 def cluster_verification_update(context, verification_id, values):
