@@ -166,11 +166,14 @@ class Engine(object):
     def _configure_instance_etc_hosts(self, instance, cluster):
         LOG.debug('Configuring "/etc/hosts" of instance.')
         hosts_file = cluster_utils.generate_etc_hosts(cluster)
+        hostname = instance.fqdn()
         with instance.remote() as r:
             r.write_file_to('etc-hosts', hosts_file)
-            r.execute_command('sudo hostname %s' % instance.fqdn())
-            r.execute_command('sudo mv etc-hosts /etc/hosts')
-
+            r.write_file_to('etc-hostname', hostname)
+            r.execute_command('sudo hostname %s' % hostname)
+            r.execute_command('sudo cp etc-hosts /etc/hosts')
+            r.execute_command('sudo cp etc-hostname /etc/hostname')
+            r.execute_command('sudo rm etc-hosts  etc-hostname')
             r.execute_command('sudo usermod -s /bin/bash $USER')
 
     def _configure_instance_resolve_conf(self, instance):
