@@ -14,8 +14,8 @@
 # limitations under the License.
 
 import os
+from unittest import mock
 
-import mock
 
 import sahara.exceptions as ex
 from sahara.service.edp.job_utils import ds_manager
@@ -263,6 +263,7 @@ class TestStorm(base.SaharaTestCase):
         master = mock.Mock()
         master.execute_command.return_value = (return_code,
                                                self.storm_topology_name)
+        master.get_python_version.return_value = 'python'
         master.hostname.return_value = self.master_host
         master.id = self.master_inst
         return master
